/*!
 * center2canvas.js
 * Example script for overlay of 2 canvas 
 * The first canvas is basically a title screen
 * When it is clicked on the second canvas will be displayed
 * The second canvas displays a snowfall effect
 * References:
 *    Snow Code is derived from: http://thecodeplayer.com/walkthrough/html5-canvas-snow-effect?s=rlt
 * See also:
 *   http://stackoverflow.com/questions/2588181/canvas-is-stretched-when-using-css-but-normal-with-width-height-properties
 *   and: 
 *   http://stackoverflow.com/questions/1152203/centering-a-canvas
 *
 *  Code setup by Brent M. Dingle
 */
 
window.addEventListener("resize", OnResizeCalled, false);

function OnResizeCalled() {

	var canvas1 = document.getElementById("canvas001");
	var canvas2 = document.getElementById("canvas002");
	
	UpdateCanvas(canvas1);
	UpdateCanvas(canvas2);
}

function UpdateCanvas(canvas) {
	
	console.log("Update Canvas Called");
	
	// Here's the tricky part 
	// - Set the width and height of the canvas's coordinate system
	// - if not specified it defaults to width=300 and height=150
	// This is the size you "pretend" your world is (i.e. optimal)
	// 
	canvas.width = 800;
	canvas.height = 480;
	
	// DEBUG: console.log(canvas.width + " " + canvas.height);
	// DEBUG: console.log("W " + window.innerWidth + " " + window.innerHeight);
	
	// Now we consider the actual display (the style width and height)
	// -- this is the size of the window you are using to view your world

    // canvas.style.width = window.innerWidth + 'px';       // This line and the next resize things
    // canvas.style.height = window.innerHeight + 'px';     // but do not maintain scale ratio
	
	// The below scale the game and maintain a ratio of 800x480 
	// by "adding" empty space to the right and bottom of the canvas as appropriate
	// You may need to put a box around the canvas to better see this
	
	var gameWidth = window.innerWidth;
	var gameHeight = window.innerHeight;
	var scaleToFitX = gameWidth / 800;
	var scaleToFitY = gameHeight / 480;

	var currentScreenRatio = gameWidth / gameHeight;
	var optimalRatio = Math.min(scaleToFitX, scaleToFitY);

	canvas.style.position = "fixed";
	
	if (currentScreenRatio >= 1.77 && currentScreenRatio <= 1.79) {
		canvas.style.width = gameWidth + "px";
		canvas.style.height = gameHeight + "px";
		canvas.style.left = 0 + "px";
	}
	else {
		canvas.style.width = 800 * optimalRatio + "px";
		canvas.style.height = 480 * optimalRatio + "px";
		canvas.style.left = ( (gameWidth - (800 * optimalRatio)) / 2 ) + "px";

	}
	
	
	// ----------------------------------- Init/Redraw the "title" canvas
	var can1 = document.getElementById("canvas001");
	var context1 = can1.getContext("2d");

	context1.font="30px Verdana";
	// Create gradient
	var gradient=context1.createLinearGradient(0,0,can1.width,0);
	gradient.addColorStop("0","magenta");
	gradient.addColorStop("0.5","blue");
	gradient.addColorStop("1.0","red");
	// Fill with gradient
	context1.fillStyle=gradient;
	context1.fillText("Click To Start Snow",10,50); 
	
	
}


 window.onload = function(){

	// Size both canvas to correct Ratio before doing anything (only needed if resizing and centring)
	OnResizeCalled();

	// Init Canvas variables
	var can1 = document.getElementById("canvas001");
	var canvas = document.getElementById("canvas002");
	var ctx = canvas.getContext("2d");

	// ----------------------------------- Setup Canvases to register clicks
	can1.addEventListener('click', 
						function() { canvas.style.display="block";
									  can1.style.display="none";
									}, false);

	canvas.addEventListener('click', 
						function() { canvas.style.display="none";
									  can1.style.display="block";
									}, false);
	
	// ----------------------------------- Snow Canvas Stuff Begins Automatically
	// ----------------------------------- But will be hidden until Canvas001 is clicked on
	//canvas dimensions -- if allowing window resize and center
	var W = canvas.width;
	var H = canvas.height;

	//canvas dimensions -- if NOT allowing window resize and center
	//var W = window.innerWidth;
	//var H = window.innerHeight;
	//canvas.width = W;
	//canvas.height = H;
	
	//snowflake particles
	var mp = 35; //max particles
	var particles = [];
	for(var i = 0; i < mp; i++)
	{
		particles.push({
			x: Math.random()*W, //x-coordinate
			y: Math.random()*H, //y-coordinate
			r: Math.random()*4+1, //radius
			d: Math.random()*mp //density
		})
	}
	
	// hide the canvas
	// var Canvas2isVisible = 0;
	canvas.style.display="none";

	//Lets draw the flakes
	function draw()
	{
		ctx.clearRect(0, 0, W, H);
		
		ctx.fillStyle = "rgba(255, 255, 255, 0.8)";
		ctx.beginPath();
		for(var i = 0; i < mp; i++)
		{
			var p = particles[i];
			ctx.moveTo(p.x, p.y);
			ctx.arc(p.x, p.y, p.r, 0, Math.PI*2, true);
		}
		ctx.fill();
		update();
	}
	
	//Function to move the snowflakes
	//angle will be an ongoing incremental flag. Sin and Cos functions will be applied to it to create vertical and horizontal movements of the flakes
	var angle = 0;
	function update()
	{
		angle += 0.01;
		for(var i = 0; i < mp; i++)
		{
			var p = particles[i];
			//Updating X and Y coordinates
			//We will add 1 to the cos function to prevent negative values which will lead flakes to move upwards
			//Every particle has its own density which can be used to make the downward movement different for each flake
			//Lets make it more random by adding in the radius
			p.y += Math.cos(angle+p.d) + 1 + p.r/2;
			p.x += Math.sin(angle) * 2;
			
			//Sending flakes back from the top when it exits
			//Lets make it a bit more organic and let flakes enter from the left and right also.
			if(p.x > W+5 || p.x < -5 || p.y > H)
			{
				if(i%3 > 0) //66.67% of the flakes
				{
					particles[i] = {x: Math.random()*W, y: -10, r: p.r, d: p.d};
				}
				else
				{
					//If the flake is exitting from the right
					if(Math.sin(angle) > 0)
					{
						//Enter from the left
						particles[i] = {x: -5, y: Math.random()*H, r: p.r, d: p.d};
					}
					else
					{
						//Enter from the right
						particles[i] = {x: W+5, y: Math.random()*H, r: p.r, d: p.d};
					}
				}
			}
		}
	}
	
	//animation loop
	setInterval(draw, 33);
}
